
#### Function to load data and format them to the right units



loadAndFormatSTECF_FDI_DATA <- function(WD, 
                                        ageOrLength, 
                                        listYears) {
  
  #load data--------
  ## load catches by countries corresponding to table A--------- 
  print("load catches")
  for (Year in listYears) {
    if (Year == listYears[1]) {
      catchesTot <- read.csv2(paste0(WD, 'FDI Catches by country', Year, '.csv'),stringsAsFactors=FALSE, sep=',')    
    } else {
      tmp <- read.csv2(paste0(WD, 'FDI Catches by country', Year, '.csv'),stringsAsFactors=FALSE, sep=',') 
      catchesTot <- bind_rows(catchesTot, tmp)
    }
  
  }
  rm(tmp)
  ## load landing struc (tables F or E)----
  print(paste("load landings structure", ageOrLength))
  if (ageOrLength == "length") {
    landingsStruc <- read.csv2(paste0(WD, 'FDI Landings Length.csv'),stringsAsFactors=FALSE, sep=',')
    landingsStruc <- rename(landingsStruc, mean_weight_landings = mean_weight_at_length)
  } else {
    landingsStruc <- read.csv2(paste0(WD, 'FDI Landings Age.csv'),stringsAsFactors=FALSE, sep=',')
    landingsStruc <- rename(landingsStruc, mean_weight_landings = mean_weight)
    landingsStruc <- rename(landingsStruc, no_age_landings = no_age)
    
  }
  
  ## load discard struc (tables C or D)----
  print(paste("load discards structure", ageOrLength))
  if (ageOrLength == "length") {
    discardsStruc <- read.csv2(paste0(WD, 'FDI Discards Length.csv'),stringsAsFactors=FALSE, sep=',')
    discardsStruc <- rename(discardsStruc, mean_weight_discards = mean_weight_at_length)
    
  } else {
    discardsStruc <- read.csv2(paste0(WD, 'FDI Discards Age.csv'),stringsAsFactors=FALSE, sep=',')
    discardsStruc <- rename(discardsStruc, mean_weight_discards = mean_weight)
    discardsStruc <- rename(discardsStruc, no_age_discards = no_age)
  }
  
  #Formating----
  
  ## table A--------- 
  print("formatting catches")
  catchesTot$total_live_weight_landed <- as.numeric(as.character(catchesTot$total_live_weight_landed))
  catchesTot$tot_discards_tonnes <- as.numeric(as.character(catchesTot$tot_discards_tonnes))
  
  ## landing struc (tables F or E)----
  print(paste("formatting landings structure", ageOrLength))
  print(table(landingsStruc$weight_unit))
  # remove NK
  landingsStruc <- landingsStruc %>% filter( weight_unit != "NK")
  landingsStruc$total_live_weight_landed <- as.numeric(as.character(landingsStruc$total_live_weight_landed))
  
  # change everything to kg
  landingsStruc$mean_weight_landings <- as.numeric(as.character(landingsStruc$mean_weight_landings)) 
  landingsStruc$mean_weight_landings[landingsStruc$weight_unit=="g"] <-   landingsStruc$mean_weight_landings[landingsStruc$weight_unit=="g"] / 1000
  landingsStruc$weight_unit[landingsStruc$weight_unit=="g"] <-   "kg"
  print(table(landingsStruc$weight_unit))

  
  print(table(landingsStruc$length_unit))
  if (ageOrLength == "length") {
    landingsStruc$length <- as.numeric(as.character(landingsStruc$length))
    landingsStruc$length[landingsStruc$length_unit=="mm"] <-   landingsStruc$length[landingsStruc$length_unit=="mm"] / 10
    
    landingsStruc$no_length <- as.numeric(as.character(landingsStruc$no_length)) 
    landingsStruc <- landingsStruc %>% rename(no_length_landings = no_length)
  } else {
    landingsStruc$no_age_landings <- as.numeric(as.character(landingsStruc$no_age_landings)) 
    landingsStruc$age <- as.numeric(as.character(landingsStruc$age))   
    
    landingsStruc$mean_length <- as.numeric(as.character(landingsStruc$mean_length))
    landingsStruc$mean_length[landingsStruc$length_unit=="mm"] <-   landingsStruc$mean_length[landingsStruc$length_unit=="mm"] / 10
  }
  
  landingsStruc$length_unit[landingsStruc$length_unit=="mm"] <-   "cm"
  print(table(landingsStruc$length_unit))
  
  
  ## discards struc (tables F or E)----
  print(paste("formatting discards structure", ageOrLength))
  print(table(discardsStruc$weight_unit))
  # remove NK
  discardsStruc <- discardsStruc %>% filter( weight_unit != "NK")
  discardsStruc$tot_discards_tonnes <- as.numeric(as.character(discardsStruc$tot_discards_tonnes))
  discardsStruc$total_live_weight_landed <- as.numeric(as.character(discardsStruc$total_live_weight_landed))
  # change everything to kg
  discardsStruc$mean_weight_discards <- as.numeric(as.character(discardsStruc$mean_weight_discards)) 
  discardsStruc$mean_weight_discards[discardsStruc$weight_unit=="g"] <-   discardsStruc$mean_weight_discards[discardsStruc$weight_unit=="g"] / 1000
  discardsStruc$weight_unit[discardsStruc$weight_unit=="g"] <-   "kg"
  print(table(discardsStruc$weight_unit))
  
  
  print(table(discardsStruc$length_unit))
  if (ageOrLength == "length") {
    discardsStruc$length <- as.numeric(as.character(discardsStruc$length))
    discardsStruc$length[discardsStruc$length_unit=="mm"] <-   discardsStruc$length[discardsStruc$length_unit=="mm"] / 10
    
    discardsStruc$no_length <- as.numeric(as.character(discardsStruc$no_length)) 
    discardsStruc <- discardsStruc %>% rename(no_length_discards = no_length)
  } else {
    discardsStruc$no_age_discards <- as.numeric(as.character(discardsStruc$no_age_discards)) 
    discardsStruc$age <- as.numeric(as.character(discardsStruc$age))   
    
    discardsStruc$mean_length <- as.numeric(as.character(discardsStruc$mean_length))
    discardsStruc$mean_length[discardsStruc$length_unit=="mm"] <-   discardsStruc$mean_length[discardsStruc$length_unit=="mm"] / 10
  }
  
  discardsStruc$length_unit[discardsStruc$length_unit=="mm"] <-   "cm"
  print(table(discardsStruc$length_unit))
  
  # save data-----
  saveRDS(catchesTot, file = paste0(WD,"catchTot.rds"))
  saveRDS(discardsStruc, file = paste0(WD, "discardsStruc", ageOrLength, ".rds"))
  saveRDS(landingsStruc, file = paste0(WD, "landingsStruc", ageOrLength, ".rds"))
  
  
}



